@@ -1,11 +1,8 @@
 package Kwiki::Hub;
 use strict;
+use warnings;
 use Spoon::Hub '-Base';
 
-sub init { 
-#     $self->load_class('cgi');
-}
-
 sub action {
     $self->cgi->action || 'display';
 }
